@@ -749,7 +749,7 @@ static int acngfs_write(const char *path, const char *buf, size_t size,
 
 static int acngfs_statfs(const char *path, struct statvfs *stbuf)
 {
-   memcpy(stbuf, &stfsTemp, sizeof(stbuf));
+   memcpy(stbuf, &stfsTemp, sizeof(*stbuf));
 	return 0;
 }
 
