@@ -58,7 +58,7 @@ class dlcon : public lockable
     	UINT m_bManualMode;
 
     	/// blacklist for permanently failing hosts, with error message
-    	MYSTD::map<MYSTD::pair<cmstring,cmstring>, mstring> m_blacklist;
+    	MYMAP<MYSTD::pair<cmstring,cmstring>, mstring> m_blacklist;
     	void BlacklistMirror(tDlJobPtr &failJob, cmstring &msg);
     	bool SetupJobConfig(tDlJobPtr &job, mstring *pReasonMsg);
 
