@@ -124,7 +124,7 @@ public:
 
 	// related to GetRegisteredFileItem but used for registration of custom file item
 	// implementations created elsewhere (which still need to obey regular work flow)
-	static bool RegisterFileItem(mstring sPathRel, SHARED_PTR<fileitem> spCustomFileItem);
+	static bool RegisterFileItem(SHARED_PTR<fileitem> spCustomFileItem);
 
 	// public constructor wrapper, get a unique object from the map
 	static tFileItemPtr GetRegisteredFileItem(mstring sPath); // also opens the cached file and increases reference count
