@@ -85,6 +85,9 @@ class job {
       bool ParseRange();
 
       off_t m_nRangeFrom, m_nRangeTo;
+
+      int m_nRedirRemaining;
+      bool CreateRedirect(header &respHead);
 };
 
 #endif
