@@ -767,7 +767,7 @@ bool tCacheMan::Inject(cmstring &from, cmstring &to,
 	};
 	tInjectItem *p=new tInjectItem(to, bTryLink);
 	SHARED_PTR<fileitem> fi(static_cast<fileitem*>(p));
-	if (!fi || !fileitem::RegisterFileItem(to, fi) )
+	if (!fi || !fileitem::RegisterFileItem(fi) )
 	{
 		MTLOGASSERT(false, "Couldn't register copy item");
 		return false;
