@@ -658,22 +658,23 @@ void fileitem::Unreg()
 tFileItemPtr fileitem::GetRegisteredFileItem(MYSTD::string sPathKey)
 {
 	LOGSTART2s("fileitem::GetFileItem", sPathKey);
-
 	tFileItemPtr p;
 	MYTRY
 	{
+		p.reset(new fileitem(sPathKey)); // let it create real target path
 		lockguard lockGlobalMap(mapLck);
 
-		map<string, tFileRefEntry>::iterator it=mapItems.find(sPathKey);
+		map<string, tFileRefEntry>::iterator it=mapItems.find(p->m_sPathRel);
 		if(it!=mapItems.end())
 		{
 			it->second.nRefCount++;
 			LOG("Sharing existing file item");
 			return it->second.ref;
 		}
-		p.reset(new fileitem(sPathKey));
+		// ok, keep the new item
+
 		LOG("Created new file item");
-		tFileRefEntry & entry = mapItems[sPathKey];
+		tFileRefEntry & entry = mapItems[p->m_sPathRel];
 		LOG("Registering new file item...");
 		if(!entry.ref)
 		{
@@ -685,26 +686,23 @@ tFileItemPtr fileitem::GetRegisteredFileItem(MYSTD::string sPathKey)
 	}
 	MYCATCH(MYSTD::bad_alloc&)
 	{
-		if(p)
-			p.reset();
+		p.reset();
 		return p;
 	}
-	return p;
 }
 
-bool fileitem::RegisterFileItem(mstring sPathRel,
-		SHARED_PTR<fileitem> spCustomFileItem)
+bool fileitem::RegisterFileItem(SHARED_PTR<fileitem> spCustomFileItem)
 		{
-			if (sPathRel.empty() || !spCustomFileItem)
+			if (!spCustomFileItem || spCustomFileItem->m_sPathRel.empty())
 				return false;
 
 			lockguard lockGlobalMap(mapLck);
 
-			map<string, tFileRefEntry>::iterator it = mapItems.find(sPathRel);
+			map<string, tFileRefEntry>::iterator it = mapItems.find(spCustomFileItem->m_sPathRel);
 			if (it != mapItems.end())
 				return false; // conflict, another agent is already active
 
-			tFileRefEntry & entry = mapItems[sPathRel];
+			tFileRefEntry & entry = mapItems[spCustomFileItem->m_sPathRel];
 			entry.ref = spCustomFileItem;
 			entry.nRefCount = 1;
 
