@@ -242,7 +242,8 @@ job::job(header *h, con *pParent) :
 	m_nAllDataCount(0),
 	m_nChunkRemainingBytes(0),
 	m_type(FILE_INVALID),
-	m_nRangeFrom(-1), m_nRangeTo(-1)
+	m_nRangeFrom(-1), m_nRangeTo(-1),
+	m_nRedirRemaining(acfg::redirmax)
 {
 	LOGSTART2("job::job", "job creating, " << m_pReqHead->frontLine << " and this: " << uintptr_t(this));
 }
@@ -485,6 +486,43 @@ inline bool job::ParseRange()
 	return false;
 }
 
+bool job::CreateRedirect(header & respHead)
+{
+	int st = respHead.getStatus();
+	if (m_nRedirRemaining <= 0 || (st != 301 && st != 302) // redir limit reached or not redirect
+	|| !respHead.h[header::LOCATION] || !respHead.h[header::LOCATION][0]) // or nonsense
+		return false;
+
+	MYTRY
+	{
+		header *xheader = new header(*m_pReqHead);
+		// it's previous server's job to not send any crap. Just make sure that the format is right...
+		xheader->frontLine = string("GET ");
+		for (const char *p = respHead.h[header::LOCATION]; *p; ++p)
+		{
+			if (isspace((unsigned char) *p))
+			{
+				xheader->frontLine += "%";
+				xheader->frontLine += BytesToHexString((uint8_t*) p, 1);
+			}
+			else
+				xheader->frontLine += *p;
+		}
+		xheader->frontLine += " HTTP/1.1";
+		job *pReplacement = m_pParentCon->AddNewJob(xheader);
+		if (!pReplacement)
+			return false;
+		pReplacement->m_nRedirRemaining = m_nRedirRemaining - 1;
+	}
+	MYCATCH(...)
+	{
+		return false;
+	}
+	return true;
+}
+
+
+
 void job::PrepareDownload() {
 
     LOGSTART("job::PrepareDownload");
@@ -833,6 +871,10 @@ job::eJobResult job::SendData(int confd, int nAllJobCount)
 						return R_AGAIN;
 					m_state=STATE_SEND_BUFFER;
 					m_backstate=STATE_HEADER_SENT; // could be changed while creating header
+
+					if(CreateRedirect(respHead))
+						return R_DONE;
+
 					const char *szErr = BuildAndEnqueHeader(fistate, nGoodDataSize, respHead);
 					if(szErr) THROW_ERROR(szErr);
 					USRDBG(REPLEVEL, "Prepared response header for user: \n" << m_sendbuf );
@@ -1171,3 +1213,6 @@ void job::SetErrorResponse(const char * errorLine)
 	//aclog::err(tSS() << "fileitem is now " << uintptr_t(m_pItem.get()));
 	m_state=STATE_SEND_MAIN_HEAD;
 }
+
+
+
