@@ -58,7 +58,7 @@ mstring GetBaseName(const string &in)
 		return "";
 
 	tStrPos end = in.find_last_not_of(CPATHSEP); // must be the last char of basename
-	if(end == stmiss) // just a slash?
+	if(end == stmiss) // empty, or just a slash?
 		return "/";
 	
 	tStrPos start = in.rfind(CPATHSEP, end);
