@@ -59,14 +59,17 @@ void tStaticFileSend::Run(const string &cmd)
 
 	string contents;
 	filereader fr;
-	if(!fr.OpenFile(acfg::confdir+SZPATHSEP+m_sFileName))
-		contents="Information about APT configuration not available, "
-				"please contact the system administrator.";
-	else
+	if(fr.OpenFile(acfg::confdir+SZPATHSEP+m_sFileName) ||
+			(!acfg::suppdir.empty() && fr.OpenFile(acfg::suppdir+SZPATHSEP+m_sFileName)))
 	{
 		contents.assign(fr.GetBuffer(), fr.GetSize());
 		ModContents(contents, cmd);
 	}
+	else
+	{
+		contents="Information about APT configuration not available, "
+				"please contact the system administrator.";
+	}
 	tSS buf(1023);
 	buf << "HTTP/1.1 " << (m_sHttpCode ? m_sHttpCode : "200")
 			<< " OK\r\nConnection: close\r\nContent-Type: "
@@ -76,7 +79,6 @@ void tStaticFileSend::Run(const string &cmd)
 	SendRawData(contents.data(), contents.length(), 0);
 }
 
-
 void tDeleter::ModContents(mstring & contents, cmstring &cmd)
 {
 #define BADCHARS "<>\"'|\t"
