@@ -213,7 +213,7 @@ struct tHostHint // could derive from pair but prefer to save some bytes with re
 		return rel ? rel < 0 : pPort < b.pPort;
 	}
 };
-typedef multimap<tHostHint, std::pair<tTcpHandlePtr, time_t> > tConPool;
+typedef multimap<tHostHint, MYSTD::pair<tTcpHandlePtr, time_t> > tConPool;
 tConPool spareConPool;
 
 tTcpHandlePtr tcpconnect::CreateConnected(cmstring &sHostname, cmstring &sPort,
